==> core_exporters_app-1.17.0.tar.gz: core_exporters_app-1.17.0/tests/test_settings.py <==
from core_main_app.utils.databases.mongoengine_database import Database
import os

SECRET_KEY = "fake-key"

INSTALLED_APPS = [
    # Django apps
    "django.contrib.admin",
    "django.contrib.auth",
    "django.contrib.contenttypes",
    "django.contrib.sessions",
    "django.contrib.messages",
    "django.contrib.sites",
    # Local apps
    "tests",
]

MIDDLEWARE = (
    "django.contrib.auth.middleware.AuthenticationMiddleware",
    "django.contrib.messages.middleware.MessageMiddleware",
    "django.contrib.sessions.middleware.SessionMiddleware",
)

TEMPLATES = [
    {
        "BACKEND": "django.template.backends.django.DjangoTemplates",
        "DIRS": ["templates"],
        "APP_DIRS": True,
        "OPTIONS": {
            "context_processors": [
                "django.template.context_processors.debug",
                "django.template.context_processors.request",
                "django.contrib.auth.context_processors.auth",
                "django.contrib.messages.context_processors.messages",
                "django.template.context_processors.i18n",
            ],
        },
    },
]

# IN-MEMORY TEST DATABASE
DATABASES = {
    "default": {
        "ENGINE": "django.db.backends.sqlite3",
        "NAME": ":memory:",
        "USER": "",
        "PASSWORD": "",
        "HOST": "",
        "PORT": "",
    },
}
MOCK_DATABASE_NAME = "db_mock"
MOCK_DATABASE_HOST = "mongomock://localhost"

CAN_ANONYMOUS_ACCESS_PUBLIC_DOCUMENT = False

database = Database(MOCK_DATABASE_HOST, MOCK_DATABASE_NAME)
database.connect()


AUTO_SET_PID = os.getenv("AUTO_SET_PID", "False").lower() == "true"
""" boolean: enable SAML2 SSO authentication.
"""

# Update Django Settings
if AUTO_SET_PID:
    INSTALLED_APPS = INSTALLED_APPS + ("core_linked_records_app",)

==> core_exporters_app-2.0.0b1.tar.gz: core_exporters_app-2.0.0b1/tests/test_settings.py <==
SECRET_KEY = "fake-key"

INSTALLED_APPS = [
    # Django apps
    "django.contrib.admin",
    "django.contrib.auth",
    "django.contrib.contenttypes",
    "django.contrib.sessions",
    "django.contrib.messages",
    "django.contrib.sites",
    "django_celery_beat",
    # Local apps
    "tests",
    "core_main_app",
    "core_explore_common_app",
    "core_exporters_app",
]

MIDDLEWARE = (
    "django.contrib.auth.middleware.AuthenticationMiddleware",
    "django.contrib.messages.middleware.MessageMiddleware",
    "django.contrib.sessions.middleware.SessionMiddleware",
)

TEMPLATES = [
    {
        "BACKEND": "django.template.backends.django.DjangoTemplates",
        "DIRS": ["templates"],
        "APP_DIRS": True,
        "OPTIONS": {
            "context_processors": [
                "django.template.context_processors.debug",
                "django.template.context_processors.request",
                "django.contrib.auth.context_processors.auth",
                "django.contrib.messages.context_processors.messages",
                "django.template.context_processors.i18n",
            ],
        },
    },
]

# IN-MEMORY TEST DATABASE
DATABASES = {
    "default": {
        "ENGINE": "django.db.backends.sqlite3",
        "NAME": ":memory:",
        "USER": "",
        "PASSWORD": "",
        "HOST": "",
        "PORT": "",
    },
}

DEFAULT_AUTO_FIELD = "django.db.models.AutoField"
CAN_ANONYMOUS_ACCESS_PUBLIC_DOCUMENT = False
CELERYBEAT_SCHEDULER = "django_celery_beat.schedulers:DatabaseScheduler"
